@@ -1,11 +1,14 @@
 import six
 from abc import abstractmethod
 from collections import defaultdict
+from itertools import chain
+from functools import partial
 import numpy as np
 import pandas as pd
 import matplotlib.pyplot as plt
 from psyplot.docstring import docstrings, safe_modulo, dedents, dedent
 from psyplot.data import InteractiveList
+from psyplot import utils
 from psyplot.compat.pycompat import filter
 from psyplot.plotter import (
     Plotter, Formatoption, rcParams, START)
@@ -173,6 +176,11 @@ class TextBase(object):
         self._enhanced_attrs = self.plotter.get_enhanced_attrs(*args, **kwargs)
         return self._enhanced_attrs
 
+    def get_fmt_widget(self, parent, project):
+        """Create a combobox with the attributes"""
+        from psy_simple.widgets.texts import LabelWidget
+        return LabelWidget(parent, self, project)
+
 
 docstrings.params['fontweights'] = dedents("""
     float
@@ -251,6 +259,13 @@ def label_weight(base, label_name=None, children=[], parents=[],
             for text in getattr(self, base.key).texts:
                 text.set_weight(value)
 
+        def get_fmt_widget(self, parent, project):
+            """Get a widget with the different font weights"""
+            from psy_simple.widgets.texts import FontWeightWidget
+            return FontWeightWidget(
+                parent, self, next(iter(getattr(self, base.key).texts), None),
+                base)
+
     return LabelWeight(base.key + 'weight')
 
 
@@ -304,8 +319,16 @@ def label_size(base, label_name=None, children=[], parents=[],
             for text in getattr(self, base.key).texts:
                 text.set_size(value)
 
+        def get_fmt_widget(self, parent, project):
+            """Get a widget with the different font weights"""
+            from psy_simple.widgets.texts import FontSizeWidget
+            return FontSizeWidget(
+                parent, self, next(iter(getattr(self, base.key).texts), None),
+                base)
+
     return LabelSize(base.key + 'size')
 
+
 docstrings.keep_params('label_weight.parameters', 'base', 'label_name')
 
 
@@ -404,6 +427,13 @@ def label_props(base, label_name=None, children=[], parents=[],
                 text.update(fontprops)
             self._todefault = False
 
+        def get_fmt_widget(self, parent, project):
+            """Get a widget with the different font weights"""
+            from psy_simple.widgets.texts import FontPropertiesWidget
+            return FontPropertiesWidget(
+                parent, self, next(iter(getattr(self, base.key).texts), None),
+                base)
+
     return LabelProps(base.key + 'props')
 
 
@@ -668,7 +698,7 @@ class Text(TextBase, Formatoption):
         self._texts_to_remove.clear()
 
     def remove(self):
-        for t in six.itervalues(self._texts):
+        for t in chain.from_iterable(six.itervalues(self._texts)):
             t.remove()
         self._texts.clear()
 
@@ -716,14 +746,12 @@ class ValueMaskBase(Formatoption):
     def update(self, value):
         if value is None:
             pass
-        elif isinstance(self.data, InteractiveList):
-            for i, data in enumerate(self.data):
-                self.data[i] = self._mask_data(data, value)
         else:
-            self.data = self._mask_data(self.data, value)
+            for i, data in enumerate(self.iter_data):
+                self.set_data(self._mask_data(data, value), i)
 
     def _mask_data(self, data, value):
-        data = data.copy(True)
+        data = data.copy(True).load()
         data.values[~np.isnan(data.values)] = self.mask_func(
             data.values[~np.isnan(data.values)], value)
         return data
