@@ -16,6 +16,7 @@ from matplotlib.rcsetup import (
     ValidateInStrings, validate_int, validate_legend_loc,
     validate_nseq_float, validate_colorlist)
 from psy_simple import __version__ as plugin_version
+import xarray as xr
 
 
 def get_versions(requirements=True):
@@ -232,6 +233,12 @@ def validate_axiscolor(value):
     return value
 
 
+def validate_dataarray(val):
+    if not isinstance(val, xr.DataArray):
+        raise ValueError("Require xarray.DataArray, not %r" % type(val))
+    return val
+
+
 def validate_marker(val):
     """Does not really make a validation because markers can be quite of
     different types"""
@@ -451,6 +458,38 @@ class ValidateList(object):
         return l
 
 
+def validate_err_calc(val):
+    """Validation function for the
+    :attr:`psy_simple.plotter.FldmeanPlotter.err_calc` formatoption"""
+    try:
+        val = validate_float(val)
+    except (ValueError, TypeError):
+        pass
+    else:
+        if val <= 100 and val >= 0:
+            return val
+        raise ValueError("Percentiles for the error calculation must lie "
+                         "between 0 and 100, not %s" % val)
+    try:
+        val = ValidateList(float, 2)(val)
+    except (ValueError, TypeError):
+        pass
+    else:
+        if all((v <= 100 and v >= 0) for v in val):
+            return val
+        raise ValueError("Percentiles for the error calculation must lie "
+                         "between 0 and 100, not %s" % val)
+    try:
+        val = validate_str(val)
+    except ValueError:
+        pass
+    else:
+        if 'std' not in val:
+            raise ValueError(
+                'A string for the error calculation must contain std!')
+    return val
+
+
 class DictValValidator(object):
     """A validation class for formatoptions that expect dictionaries as values
     """
@@ -596,6 +635,13 @@ rcParams = RcParams(defaultParams={
              'prefer_list': True,
              'default_slice': None,
              'summary': 'Make a line plot of one-dimensional data'},
+         'fldmean': {
+             'module': 'psy_simple.plotters',
+             'plotter_name': 'FldmeanPlotter',
+             'prefer_list': True,
+             'default_slice': None,
+             'summary': 'Calculate and plot the mean over x- and y-dimensions'
+             },
          'density': {
              'module': 'psy_simple.plotters',
              'plotter_name': 'DensityPlotter',
@@ -762,7 +808,8 @@ rcParams = RcParams(defaultParams={
 
     # density plotter
     'plotter.density.coord': [
-        None, try_and_error(validate_none, validate_str, validate_stringlist),
+        None, try_and_error(validate_none, validate_dataarray,
+                            validate_str, validate_stringlist),
         'Alternative x-coordinate to use for DensityPlotter'],
     'plotter.density.xrange': [
         'minmax', validate_limits, 'The histogram limits of the density plot'],
@@ -789,7 +836,8 @@ rcParams = RcParams(defaultParams={
 
     # SimplePlot
     'plotter.line.coord': [
-        None, try_and_error(validate_none, validate_str, validate_stringlist),
+        None, try_and_error(validate_none, validate_dataarray,
+                            validate_str, validate_stringlist),
         'Alternative x-coordinate to use for LinePlotter'],
     'plotter.line.plot': [
         '-', validate_lineplot,
@@ -809,7 +857,8 @@ rcParams = RcParams(defaultParams={
     'plotter.line.erroralpha': [
         0.15, validate_alpha, 'The alpha value of the error range'],
     'plotter.bar.coord': [
-        None, try_and_error(validate_none, validate_str, validate_stringlist),
+        None, try_and_error(validate_none, validate_dataarray,
+                            validate_str, validate_stringlist),
         'Alternative x-coordinate to use for BarPlotter'],
     'plotter.bar.widths': [
         'equal', ValidateInStrings('spacing', ['equal', 'data'], True),
@@ -867,10 +916,25 @@ rcParams = RcParams(defaultParams={
     'plotter.simple.legend': [
         True, validate_legend, 'fmt key to draw a legend'],
 
+    # FldmeanPlotter
+    'plotter.fldmean.mean': [
+        'mean', try_and_error(
+            ValidateInStrings('mean', ['mean', 'median'], True),
+            validate_float),
+        "The calculation result, either the 'mean', 'median' or a percentile"],
+    'plotter.fldmean.err_calc': [
+        'std', validate_err_calc,
+        "The error calculation method, either the 'std' or a minimum "
+        "and maximum percentile"],
+
     # Plot2D
+    'plotter.plot2d.interp_bounds': [
+        None, validate_bool_maybe_none,
+        'Switch to interpolate the bounds for 2D plots'],
     'plotter.plot2d.plot': [
         'mesh', try_and_error(validate_none, ValidateInStrings(
-            '2d plot', ['mesh', 'contourf', 'tri', 'tricontourf'], True)),
+            '2d plot', ['mesh', 'contourf', 'contour',
+                        'tri', 'tricontourf', 'tricontour'], True)),
         'fmt key to specify the plot type of 2D scalar plots'],
     'plotter.plot2d.plot.min_circle_ratio': [
         0.05, validate_float,
